@@ -1,9 +1,7 @@
-#[macro_use] extern crate assert_matches;
-#[allow(unused_imports)]
-#[macro_use] extern crate gumdrop;
-
 use std::str::FromStr;
 
+use assert_matches::assert_matches;
+
 use gumdrop::Options;
 
 const EMPTY: &'static [&'static str] = &[];
@@ -1137,6 +1135,7 @@ fn test_failed_parse_free() {
         |e| e.starts_with("invalid argument to option `baz`: "));
 }
 
+#[cfg(feature = "default_expr")]
 #[test]
 fn test_default_expr() {
     #[derive(Options)]
